==> dgaintel-0.1.tar.gz: dgaintel-0.1/setup.py <==

from distutils.core import setup

setup(
  name = 'dgaintel',         # How you named your package folder (MyLib)
  packages = ['dgaintel'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'predict whether a domain is genuine or DGA.',   # Give a short description about your library
  author = 'Rushil Mallarapu',                   # Type in your name
  author_email = 'rushil.mallarapu@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/sudo-rushil/dgaintel',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/sudo-rushil/dgaintel/archive/v0.1.tar.gz',    # I explain this later on
  keywords = ['DGA', 'Domain', 'Domain Generation', 'Domain Classifier', 'Deep Learning', 'AI', 'RNN', 'LSTM', 'CNN-LSTM', 'CNN'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'tensorflow',
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.7',
  ])

==> dgaintel-0.2.tar.gz: dgaintel-0.2/setup.py <==

from distutils.core import setup

setup(
  name = 'dgaintel',         # How you named your package folder (MyLib)
  packages = ['dgaintel'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'predict whether a domain is genuine or DGA.',   # Give a short description about your library
  author = 'Rushil Mallarapu',                   # Type in your name
  author_email = 'rushil.mallarapu@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/sudo-rushil/dgaintel',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/sudo-rushil/dgaintel/archive/v0.2.tar.gz',    # I explain this later on
  keywords = ['DGA', 'Domain', 'Domain Generation', 'Domain Classifier', 'Deep Learning', 'AI', 'RNN', 'LSTM', 'CNN-LSTM', 'CNN'],
  include_package_data=True,
  install_requires=[            # I get to this in a second
          'numpy',
          'tensorflow',
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.7',
  ])
